Re:ARMv7 vs. x86-64: Pathfinding benchmark of C++, D, Go, Ni...
by brucer on Sunday December 21, 2014 @02:23PM
(#8780601)
I just realized I overthought the caching scheme, and removing one check made it 3x faster :)
[ Parent
| on HN ]
Re:ARMv7 vs. x86-64: Pathfinding benchmark of C++, D, Go, Ni...
by logicchains on Monday December 22, 2014 @07:23AM
(#8782836)
Nice! That's almost as fast as the C++ one using caching; your algorithm must be better.